@@ -1,7 +1,10 @@
-# $Id: Closures.pm,v 1.6 2007/01/13 20:55:52 comdog Exp $
+# $Id: Closures.pm 2372 2007-11-09 11:51:07Z comdog $
 package File::Find::Closures;
 use strict;
 
+use warnings;
+no warnings;
+
 use vars qw( $VERSION @EXPORT_OK %EXPORT_TAGS );
 
 use Carp qw(carp croak);
@@ -10,7 +13,7 @@ use File::Basename qw(dirname);
 use File::Spec::Functions qw(canonpath no_upwards);
 use UNIVERSAL qw(isa);
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.6 $ =~ m/ (\d+) \. (\d+) /xg;
+$VERSION = 1.07;
 
 @EXPORT_OK   = qw(
 	find_regular_files
@@ -55,9 +58,6 @@ File::Find::Closures - functions you can use with File::Find
 
 =head1 DESCRIPTION
 
-SOME PARTS ARE NOT IMPLEMENTED YET!  THIS IS ALPHA ALPHA SOFTWARE: A
-MERE SHELL OF AN IDEA.
-
 I wrote this module as an example of both using closures and using
 File::Find. Students are always asking me what closures are good
 for, and here's some examples. The functions mostly stand alone (i.e.
@@ -406,7 +406,7 @@ should write your closures.
 You need to provide both closures.  Start of with the basic subroutine
 stub to do this.  Create a lexical array in the scope of the subroutine.
 The two closures will share this variable.  Create two closures: one
-of give to find() and one to access the lexical array.
+of give to C<find()> and one to access the lexical array.
 
 	sub find_by_foo
 		{
@@ -421,8 +421,8 @@ of give to find() and one to access the lexical array.
 		}
 
 The filename should be the full path to the file that you get
-from $File::Find::name, unless you are doing something wierd,
-like find_by_directory_contains().
+from C<$File::Find::name>, unless you are doing something wierd,
+like C<find_by_directory_contains()>.
 
 Once you have something, send it to me at C<< <bdfoy@cpan.org> >>. You
 must release your code under the Perl Artistic License.
